==> kmyfirewall-trinity-3.5.13.2.tar.xz: kmyfirewall-trinity-3.5.13.2/kmyfirewall/ruleoptionplugins/mark_target_option/kmfruletargetoptioneditmark.h <==
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULETARGETOPTIONEDITMARK_H
#define KMFRULETARGETOPTIONEDITMARK_H

#include "../../core/kmfruletargetoptioneditinterface.h"

// KDE includes
#include <kparts/part.h>
#include <kparts/plugin.h>
#include <kparts/factory.h>
#include <kxmlgui.h>
class KInstance;


namespace KMF {
class IPTRule;
class KMFRuleEditTargetMark;
/**
@author Christian Hubinger
*/
class KMFRuleTargetOptionEditMark : public KMFRuleTargetOptionEditInterface {
	Q_OBJECT
  TQ_OBJECT
public:
	KMFRuleTargetOptionEditMark(TQObject *parent = 0, const char *name = 0);

	~KMFRuleTargetOptionEditMark();
	void loadRule( IPTRule* rule );	
	TQWidget* editWidget();
	const TQString& optionEditName() const;
	const TQString& description() const;
	bool setTarget( const TQString& );

private slots:

	void slotShowOverview();

private:
	KMFRuleEditTargetMark *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleTargetOptionEditMarkFactory : public KLibFactory {
	Q_OBJECT
  TQ_OBJECT
public:
	KMFRuleTargetOptionEditMarkFactory( TQObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleTargetOptionEditMarkFactory() {
/* 		delete s_instance; */
	};
	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
	                               const TQStringList &args = TQStringList() );
	/*     static KInstance* instance(); */

/*private:
	static KInstance* s_instance;*/
};
}








#endif

==> kmyfirewall-trinity_14.1.0.orig.tar.xz: kmyfirewall-trinity-14.1.0/kmyfirewall/ruleoptionplugins/mark_target_option/kmfruletargetoptioneditmark.h <==
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULETARGETOPTIONEDITMARK_H
#define KMFRULETARGETOPTIONEDITMARK_H

#include "../../core/kmfruletargetoptioneditinterface.h"

// KDE includes
#include <tdeparts/part.h>
#include <tdeparts/plugin.h>
#include <tdeparts/factory.h>
#include <kxmlgui.h>
class TDEInstance;


namespace KMF {
class IPTRule;
class KMFRuleEditTargetMark;
/**
@author Christian Hubinger
*/
class KMFRuleTargetOptionEditMark : public KMFRuleTargetOptionEditInterface {
	Q_OBJECT
  
public:
	KMFRuleTargetOptionEditMark(TQObject *parent = 0, const char *name = 0);

	~KMFRuleTargetOptionEditMark();
	void loadRule( IPTRule* rule );	
	TQWidget* editWidget();
	const TQString& optionEditName() const;
	const TQString& description() const;
	bool setTarget( const TQString& );

private slots:

	void slotShowOverview();

private:
	KMFRuleEditTargetMark *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleTargetOptionEditMarkFactory : public KLibFactory {
	Q_OBJECT
  
public:
	KMFRuleTargetOptionEditMarkFactory( TQObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleTargetOptionEditMarkFactory() {
/* 		delete s_instance; */
	};
	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
	                               const TQStringList &args = TQStringList() );
	/*     static TDEInstance* instance(); */

/*private:
	static TDEInstance* s_instance;*/
};
}








#endif
